# ExBranch

Branch-based experiment management tool.

## Installation

**Currently Only Zsh is supported**

1. Install Python package
```shell
pip3 install --user --upgrade exbranch
```

2. Activate it in `~/.zshrc`
```shell
echo '[[ -o interactive ]] && source `python3 -m exbranch zsh`' >> ~/.zshrc
```

## LICENSE

Apache License 2.0

